@@ -21,7 +21,7 @@
 	regimes<-sapply(phyltree@lineages[phyltree@term],function(epch,vregimes){
 	    epch<-rev(epch)
 	    as.character(sapply(epch[-1],function(reg,vregimes){vregimes[reg]},vregimes=vregimes,simplify=TRUE))
-	},vregimes=vregimes,simplify=TRUE)
+	},vregimes=vregimes,simplify=FALSE)
     }
 
     bOKregimes<-TRUE
