@@ -202,7 +202,7 @@
     	    regimes<-sapply(PhylTree@lineages[PhylTree@term],function(epch,vregimes){
     			    epch<-rev(epch)
     			    as.character(sapply(epch[-1],function(reg,vregimes){vregimes[reg]},vregimes=vregimes,simplify=TRUE))
-    	    },vregimes=vregimes,simplify=TRUE)
+    	    },vregimes=vregimes,simplify=FALSE)
 	}                                                       
 	regimes.types.orig<-c()
 	for (i in 1: length(regimes)){regimes.types.orig<-c(regimes.types.orig,unique(regimes[[i]]))}
